/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
Diese Datei: beispiele.do
     Dateiformat: Dos\Windows
     Zeichensatz: Unicode (UTF-8 ohne BOM)   
Download: 
     https://www.gesis.org/missy/files/documents/MZ/misc/TR_10-03_STATA.zip
Version: 10/2019

Stata-Syntax zur Varianzschätzung für Mikrozensus Scientific Use Files ab 2005 
am Beispiel des Mikrozensus 2015

Beispiele
1 Designbasierte Schätzung des Gesamtwertes Zahl der Erwerbslosen
2 Schätzung des Gesamtwertes mit gebundener Hochrechnung (Regressionsschätzung) 
3 Schätzung der Erwerbslosenquote mit Designgewichtung
4 Schätzung der Erwerbslosenquote mit gebundener Hochrechnung (Regressionsschätzung) 
zu 

Schimpl-Neimanns, Bernhard: Varianzschätzung für Mikrozensus 
Scientific Use Files ab 2005. GESIS-Technical Report Nr. 2010/03. 
Mannheim: GESIS.
URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
     gesis_reihen/gesis_methodenberichte/2010/TechnicalReport_10-03.pdf
Überarbeitete Fassung veröffentlicht als:
Schimpl-Neimanns, Bernhard (2011): Schätzung des Stichprobenfehlers 
in Mikrozensus Scientific Use Files ab 2005, AStA Wirtschafts- und 
Sozialstatistisches Archiv 5 (1): 19-38. DOI: 10.1007/s11943-011-0092-4. 

Datenbeschreibung, siehe https://www.gesis.org/missy/metadata/MZ/2015/

Änderungen gegenüber früheren Versionen:
* Syntax an Version Stata/MP 15.1 angepasst und vereinfacht
* Berechnung der Mittelwerte der Indikatoren der Hilfsmerkmale mit varmz15.do
  berücksichtigt nur Bevölkerung am Hauptwohnsitz
*/

* version 15.1
clear
capture log close
set more off
set dp comma
set varabbrev off
	
* Lokales Arbeitsverzeichnis eintragen, z. B. "c:\temp"
cd "Arbeitsverzeichnis"

log using "beispiele.log", text replace

* Daten einlesen, ggf. um Verzeichnis ergänzen oder ohne Variablenauswahl
* - hier Scientific Use Files Mikrozensus 2015 
use EF1	  /// Bundesland
    EF3	  /// Nr. des Auswahlbezirks (systemfrei)
    EF4	  /// Nr. des Haushalts im Auswahlbezirk (systemfrei)
    EF5a  /// Nr. der Person im Haushalt
    EF5b  /// Jahresüberhang aus dem Vorjahr
    EF12  /// Berichtsquartal
    EF29  /// Erwerbstyp
    EF30  /// Bevölkerung: Haupt- oder Nebenwohnsitz
    EF31  /// Bevölkerung: Privathaushalte
    EF44  /// Alter
    EF46  /// Geschlecht
    EF117 /// Stellung im Beruf
    EF369 /// 1. ausl. Staatsangehörigkeit
    EF371 /// Staatsangehörigkeit typisiert
    EF570 /// Gebäudegrößenklasse
    EF951 /// Standardhochrechnungsfaktor Quartal (in 1000)
    EF952 /// Standardhochrechnungsfaktor Jahr (in 1000)
 using "mz2015.dta", replace  

* set output inform

* satznr für Zusammenführen mit Hilfsmerkmalen 
gen long satznr = _n
label var satznr "Fortlaufende Personennummer (Satznr. File)"


/* ----------------------------------------------------------------------------
Beispiel 1: Designbasierte Schätzung des Gesamtwertes Zahl der Erwerbslosen
            Jahresdurchschnittsergebnis                                      */			   

* Schichtung: Zusammenfassung der Neubauschichten
recode EF570 (6/7=6), gen(v570) copyrest
gen schicht = EF12*1000 + EF1*10 + v570
label var schicht "Schichtung: Quartal x Land x Gebäudegr.klasse"

* Klumpung: Auswahlbezirk
*  - für die Daten bis einschließlich 2011 reicht EF3 zur Kennzeichnung aus -
gen long idpsu = EF1*1000000 + EF3
label var idpsu "Auswahlbezirk (EF1 o EF3)"
format idpsu %8.0f

* Auswahlsatz: Jahresdurchschnittsergebnisse 
gen f = 0.01 * 0.7
label var f "Auswahlsatz SUF: 70 %-Substichprobe des MZ (1 %-Stichprobe)"

* Designgewicht (freie Hochrechnung)
gen d = 1/f
label var d "Designgewicht d = 1/f"

* Subpopulation
gen byte sub = (EF30>=1 & EF30<=2 & EF44>=15 & EF44<=64)
label var sub "Bevölkerung im Alter von 15 bis 64 Jahren am Hauptwohnsitz"
label def sub 1 "BevHWS 15-64 J" 0 "sonst", add modify
label val sub sub

* Interessierendes Merkmal 
gen byte y = (EF29==2) * sub
label var y "ILO-Erwerbslose, Bevölkerung 15-64 Jahre am Hauptwohnsitz"

/* 
Stichprobendesign: 
- Klumpung: idpsu Auswahlbezirksnr. (einstufige Zufallsauswahl)
- Schichtung: schicht = Berichtsquartal x Land x Gebäudegr.klasse
- Ziehen ohne Zurücklegen
- Auswahlsatz (f): 0,7 % 
- Designgewichtung: d = 1/f
- Ausschluss singulärer PSUs bei der Varianzschätzung mit singleunit(certainty)
  Varianzschätzungen sind aufgrund von Schichten mit 1 PSU nicht möglich.
  Betrifft in diesem Fall 5 Schichten der Gebäudeschicht Gemeinschaftsunterkunft
  mit insges. 36 Personen der Subpopulation, darunter sind keine Erwerbslosen (EF29=2). 
  Siehe Ergebnis von 
    svyset idpsu [pw=d] , strata(schicht) fpc(f)
    svydescribe , single generate(single)                                       
- Im Unterschied zu den Daten bis 2011 können Auswahlbezirke ohne erhobene 
  Personen, sogenannte Nullbezirke (siehe EF30=-8, -7), bei der Schätzung 
  berücksichtigt werden.
*/  
svyset idpsu [iw=d] , strata(schicht) fpc(f) singleunit(certainty)
quietly svy linearized, subpop(sub): total y 
estat cv
/* Ergebnis
             |             Linearized
             |      Total   Std. Err.     CV (%)
-------------+----------------------------------
           y |    1550428    17340,7     1,11845
*/


/* -----------------------------------------------------------------------------
Beispiel 2: Schätzung des Gesamtwertes mit gebundener Hochrechnung 
            (Regressionsschätzung) Zahl der Erwerbslosen 
			Jahresdurchschnittsergebnis                                      */

/* Hochrechnungsfaktor (gebundene Hochrechnung) Jahresdurchschnitt 
- EF952 ist im ab 2006 bereits mit Faktor 1/0.7 multipliziert.
- Hochrechnungsfaktoren sind (außer 2012) für Haushaltsmitglieder konstant. */
gen w = EF952 * 1000
label var w "Hochrechnungsfaktor geb. HR Jahr"

* Korrekturfaktor
gen g = w/d
label var g "Korrekturfaktor"

* Hilfsvariablen zuspielen (erstellt mit xvar15.do) 
merge 1:1 satznr using xvar15.dta
drop _merge

* MZ 2005 - 2011: x1-x190
* MZ 2012 - 2015: x1-x224
quietly regress y x1-x224, noconstant 
display "R-Quadrat = " e(r2) 
quietly predict e, residuals
gen u = e * g 

* Varianzschätzung mit Hochrechnungsfaktor w
svyset idpsu [iw = w],  fpc(f) strata(schicht) single(certainty)
svy linearized, subpop(sub) : total y   e
/* Ergebnis
             |             Linearized
             |      Total   Std. Err.     [95% Conf. Interval]
-------------+------------------------------------------------
           y |    1944713   
           e |              19575,05
*/


/* -----------------------------------------------------------------------------
Beispiel 3: Schätzung der Erwerbslosenquote mit Designgewichtung
			Erwerbslosenquote - Jahresdurchschnittsergebnis                  */

* Interessierendes (Nenner-)Merkmal
gen z = (EF29>=1 & EF29<=2) * sub
label var z "ILO-Erwerbspersonen" 
svyset idpsu [iw=d] , strata(schicht) fpc(f) singleunit(certainty)
quietly svy linearized, subpop(sub) : ratio ("R_Erwerbslos": y/z)
estat cv
/* Ergebnis
             |             Linearized
             |      Ratio   Std. Err.     CV (%)
-------------+----------------------------------
R_Erwerbslos |   ,0457927   ,0004928     1,07607
*/


/* -----------------------------------------------------------------------------
Beispiel 4: Schätzung der Erwerbslosenquote mit gebundener Hochrechnung 
            (Regressionsschätzung) 
			Erwerbslosenquote - Jahresdurchschnittsergebnis                  */

quietly summ y if sub==1 [iw = w]
scalar Ty = r(sum)
* display as text "Total Erwerbslos (y * w): ", as res Ty
quietly summ z if sub==1 [iw = w]
scalar Tz = r(sum)
* display as text "Total Erwerbspersonen (z * w): ", as res Tz
scalar R = Ty  / Tz
* display as text "Erwerbslosenquote: ", as res R

* diffvar: Linearisierte (score) Variable für Varianzschätzung
gen double diffvar = (y - scalar(R) * z) / scalar(Tz)
quietly regress diffvar x1-x224, noconst
predict eR , residuals 
recode  eR . = 0 if sub!=.
lab var eR "score var ratio R für Zellgewichtung"
gen uR = eR * g  
recode uR . = 0 if sub!=.
lab var uR "score var ratio R für Designgewichtung"
drop diffvar

* Varianzschätzung mit Hochrechnungsfaktor w
svyset idpsu [iw = w], strata(schicht) fpc(f) single(certainty) 
svy linearized , subpop(sub) : ratio (y / z)      // SE irrelevant
svy linearized , subpop(sub) : total eR           // Total irrelevant
/* Ergebnis
             |             Linearized
             |      Ratio   Std. Err.     [95% Conf. Interval]
-------------+------------------------------------------------
    _ratio_1 |   ,0472304   
	
             |             Linearized
             |      Total   Std. Err.     [95% Conf. Interval]
-------------+------------------------------------------------
          eR |              ,0004544
*/

* Varianzschätzung mit Designgewicht
svyset idpsu [iw = d], strata(schicht) fpc(f) single(certainty) 
svy linearized , subpop(sub) : total uR           // Total irrelevant
/* Ergebnis
             |             Linearized
             |      Total   Std. Err.     [95% Conf. Interval]
-------------+------------------------------------------------
          uR |              ,0004544
*/

exit
