/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
Diese Datei: xvar07.do
     Dateiformat: Dos\Windows
     Zeichensatz: Unicode (UTF-8 ohne BOM)   
Download: 
     https://www.gesis.org/missy/files/documents/MZ/misc/TR_10-03_STATA.zip
Version: 10/2019

Konstruktion der Hilfsmerkmale für Scientific Use File Mikrozensus 2007

Zusammenführung der Hilfsmerkmale mit SUF mittels Identifikator satznr

Siehe: 
Schimpl-Neimanns, Bernhard: Varianzschätzung für Mikrozensus 
Scientific Use Files ab 2005. GESIS-Technical Report Nr. 2010/03. 
Mannheim: GESIS.
  URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
       gesis_reihen/gesis_methodenberichte/2010/TechnicalReport_10-03.pdf
Überarbeitete Fassung veröffentlicht als:
Schimpl-Neimanns, Bernhard (2011): Schätzung des Stichprobenfehlers 
in Mikrozensus Scientific Use Files ab 2005, AStA Wirtschafts- und 
Sozialstatistisches Archiv 5 (1): 19-38. DOI: 10.1007/s11943-011-0092-4. 

Datenbeschreibung:
  https://www.gesis.org/missy/metadata/MZ/2007/

Änderungen gegenüber früheren Versionen:
* Syntax an Version Stata/MP 15.1 angepasst und vereinfacht
* Berechnung der Mittelwerte der Indikatoren der Hilfsmerkmale berücksichtigt 
  nur Bevölkerung am Hauptwohnsitz
============================================================================= */  

* version 15.1
clear
capture log close
set more off
set dp comma
set varabbrev off

* Lokales Arbeitsverzeichnis eintragen, z. B. "c:\temp"
cd "Arbeitsverzeichnis"

log using "xvar07.log", text replace

/* 
Konstruktion der Hilfsmerkmale für Scientific Use File (SUF) Mikrozensus 2007 

Zusammenführung der Hilfsmerkmale zum SUF mittels Identifikator: satznr

Beachte: Die Hilfsmerkmale werden länderspezifisch gebildet 
     Codierung der Länder im MZ 2005 und 2006 nach alphabetischer, 
     im MZ 2007 (wie bis 2004) nach geographischer Sortierung
                        Code im Mikrozensus SUF
     EF1 Bundesland       2005, 2006         2007
     --------------------------------------------
     Baden-Württemberg        01              08 
     (...)                                       
     Schleswig-Holstein       15              01 
     Thüringen                16              16 
*/


/* Rekodierung doppelter Identifikatoren im SUF 2007:
   http://www.gesis.org/fileadmin/upload/dienstleistung/daten/amtl_mikrodaten/
   mz/syntax/misc/ID_2007.do

*  use mz2007.dta, clear
*  do ID_2007.do
*  (...)
*  sort ID_Org // Sortierung des Ausgangsfile VOR Veränderungen EF4 und EF5
*  (...)
*  save "mz2007r.dta"                                                      */

* Daten einlesen, ggf. um Verzeichnis ergänzen oder ohne Variablenauswahl 
* - hier: MZ SUF 2007 mit rekodierter Haushaltsnummer (EF4R)
use EF1    /// Bundesland
    EF3    /// Nr. des Auswahlbezirks (laufend)
    EF4    /// Nr. des Haushalts im Auswahlbezirk (laufend)
    EF5    /// Nr. der Person im Haushalt (laufend)
    EF12   /// Berichtsquartal
    EF29   /// Erwerbstyp
    EF30   /// Bevölkerung: Haupt- oder Nebenwohnsitz
    EF31   /// Bevölkerung: Privathaushalte 
    EF44   /// Alter
    EF46   /// Geschlecht 
    EF117  /// Stellung im Beruf
    EF369  /// 1. Staatsangehörigkeit 
    EF371  /// Staatsangehörigkeit typisiert
    EF570  /// Gebäudegrößenklassen 
    EF952  /// Hochrechnungsfaktor: Jahr
    EF4R   /// Nr. des Haushalts im Auswahlbezirk (systemfrei) - plausibilisiert
    EF5R   /// Nr. der Person im Haushalt (EF5) rekodiert
 using "mz2007r.dta", replace

* set output inform

* satznr für späteres Zusammenführen mit MZ
gen long satznr = _n
format satznr %6.0f
label var satznr "Fortlaufende Personennummer (Satznr. File)" 

/* Vorläufige fortlaufende Haushaltsnummer bilden
* egen hhnr = group(EF1 EF3 EF4R EF12)
   Im MZ 2007 ist bei der Konstruktion der Haushaltsnummer (EF4R) das 
   Berichtsquartal (EF12) berücksichtigt, sodass auf die Verwendung 
   von EF12 bei der folgenden Haushaltsabgrenzung verzichtet werden
   kann. */
egen hhnr = group(EF1 EF3 EF4R)

bysort hhnr: gen pnr = _n
label var pnr "Personennummer im HH"

gen pnrGU = pnr*(EF31==2)
label var pnrGU "Personennummer in HH mit Pers. in Gemeinschaftsunterkunft"

drop hhnr
sort EF1 EF3 EF4R pnrGU satznr // ID

* Neue Haushaltsnummer bilden
*     Pers. in Gemeinschaftsunterkünften bilden einen eigenen "Haushalt"
egen hhnr = group(EF1 EF3 EF4R pnrGU) 
label var hhnr "Fortlaufende Haushaltsnummer (Pers in GU: eigene Nr.)"

sort satznr // ID

* === Abgrenzung der Hilfsmerkmale ===
* Siehe Übersicht 3: Realisiertes Hochrechnungsmodell nach Bundesländern 
*       im 2. Vierteljahr 2005, S. 1046 in: Afentakis, A. & Bihler, W.
*       (2005): Das Hochrechnungsverfahren beim unterjährigen Mikrozensus 
*       ab 2005, Wirtschaft und Statistik 10/2005, 1039-1048.

recode EF46 (1=0 "M") (2=1 "W"), gen(sex)
label var sex "Geschlecht EF46"

recode EF44 (0/14=1 "U15") (15/44=0 "U45") (45/95=2 "U95"), gen(age)
label var age "Altersgruppe EF44)"

recode EF371 (1=0 "DE") (2=2 "EU") (3=3 "SO"), gen(nat)
replace nat=1 if nat==3 & EF369==34
lab def nat 1 "TR", add modify
label var nat "Staatsangehörigkeit EF371, EF369"

recode EF117 (9=1 "SOLD") (10=2 "WEHR") (*=0 "ZIVB"), gen(zsw)
label var zsw "Bevölkerungsgruppe"


/* Hochrechnungsterme:
H1: Land x Bevölkerung insgesamt je Monat
H2: Land x Geschlecht (m, w) x Alter (<15, 15 bis 44, 45+ Jahre) 
H3: Land x Staatsangehörigkeit (D, TR, EU25, nEU) x Geschlecht (m, w)
H4: Land x Bevölkerungstyp (Zeit- und Berufssoldaten einschl. ...
*/
* Für Länder mit Hochrechnungstermen H1 bis H4
gen byte x001 = 1         // H1: Konstante [m, Alter=15-44, Zivilbev.]
gen byte x002 = (sex==1)            // H2: Geschlecht=w
gen byte x003 = (age==1)            // H2: Alter=<15
gen byte x004 = (age==2)            // H2: Alter=45+
gen byte x005 = (sex==1) * (age==1) // H2: Geschlecht=w x Alter=<15 
gen byte x006 = (sex==1) * (age==2) // H2: Geschlecht=w x Alter=45+ 
gen byte x007 = (nat==1)            // H3: Staatsang.=TR
gen byte x008 = (nat==2)            // H3: Staatsang.=EU
gen byte x009 = (nat==3)            // H3: Staatsang.=SO
gen byte x010 = (nat==1) * (sex==1) // H3: Staatsang.=TR x Geschlecht=w
gen byte x011 = (nat==2) * (sex==1) // H3: Staatsang.=EU x Geschlecht=w
gen byte x012 = (nat==3) * (sex==1) // H3: Staatsang.=SO x Geschlecht=w
gen byte x013 = (zsw==1)            // H4: Bevölk.gr=Soldaten
gen byte x014 = (zsw==2)            // H4: Bevölk.gr=Wehrpfl

* === Baden-Württemberg (MZ 2005-2006: EF1=01 ==> MZ 2007: EF1=8) ===
qui for var x001 x002 x003 x004 x005 x006 x007 x008 x009 x010 x011 x012 x013 x014 ///  X
      \ new x015 x016 x017 x018 x019 x020 x021 x022 x023 x024 x025 x026 x027 x028 ///  Y
  : gen byte Y=X*(EF1==8)
* === Bayern (MZ 2005-2006: EF1=02 ==> MZ 2007: EF1=9) ===
qui for var x001 x002 x003 x004 x005 x006 x007 x008 x009 x010 x011 x012 x013 x014 ///  X
      \ new x029 x030 x031 x032 x033 x034 x035 x036 x037 x038 x039 x040 x041 x042 ///  Y
  : gen byte Y=X*(EF1==9)
* === Berlin (MZ 2005-2006: EF1=03 ==> MZ 2007: EF1=11) ===
qui for var x001 x002 x003 x004 x005 x006 x007 x008 x009 x010 x011 x012 x013 x014 ///  X
      \ new x043 x044 x045 x046 x047 x048 x049 x050 x051 x052 x053 x054 x055 x056 ///  Y
  : gen byte Y=X*(EF1==11)
* === Hessen (MZ 2005-2006: EF1=07 ==> MZ 2007: EF1=6) ===
qui for var x001 x002 x003 x004 x005 x006 x007 x008 x009 x010 x011 x012 x013 x014 ///  X
      \ new x057 x058 x059 x060 x061 x062 x063 x064 x065 x066 x067 x068 x069 x070 ///  Y
  : gen byte Y=X*(EF1==6)
* === Niedersachsen (MZ 2005-2006: EF1=09 ==> MZ 2007: EF1=3) ===
qui for var x001 x002 x003 x004 x005 x006 x007 x008 x009 x010 x011 x012 x013 x014 ///  X
      \ new x071 x072 x073 x074 x075 x076 x077 x078 x079 x080 x081 x082 x083 x084 ///  Y
  : gen byte Y=X*(EF1==3)
* === Rheinland-Pfalz (MZ 2005-2006: EF1=11 ==> MZ 2007: EF1=7) ===
qui for var x001 x002 x003 x004 x005 x006 x007 x008 x009 x010 x011 x012 x013 x014 ///  X
      \ new x085 x086 x087 x088 x089 x090 x091 x092 x093 x094 x095 x096 x097 x098 ///  Y
  : gen byte Y=X*(EF1==7)
* === Schleswig-Holstein (MZ 2005-2006: EF1=15 ==> MZ 2007: EF1=1) ===
qui for var x001 x002 x003 x004 x005 x006 x007 x008 x009 x010 x011 x012 x013 x014 ///  X
      \ new x099 x100 x101 x102 x103 x104 x105 x106 x107 x108 x109 x110 x111 x112 ///  Y
  : gen byte Y=X*(EF1==1)
* === Nordrhein-Westfalen (MZ 2005-2006: EF1==10 ==> MZ 2007: EF1=5) === siehe unten 

* Reduziertes Hochrechnungsmodell H3
*    R2: Staatsangehörigkeit (deutsch, nicht deutsch) x Geschlecht
* Für Länder: Brandenburg, Mecklenburg-Vorpommern, Sachsen, Sachsen-Anhalt, Thüringen
gen xn  = (nat~=0)            // x007 - x009
gen xng = (nat~=0) * (sex==1) // x010 - x012
* === Brandenburg (MZ 2005-2006: EF1=04 ==> MZ 2007: EF1=12) ===
qui for var x001 x002 x003 x004 x005 x006 xn   xng  x013 x014 ///  X
      \ new x113 x114 x115 x116 x117 x118 x119 x120 x121 x122 ///  Y
  : gen byte Y=X*(EF1==12)
* === Mecklenburg-Vorpommern (MZ 2005-2006: EF1=08 ==> MZ 2007: EF1=13) ===
qui for var x001 x002 x003 x004 x005 x006 xn   xng  x013 x014 ///  X
      \ new x123 x124 x125 x126 x127 x128 x129 x130 x131 x132 ///  Y
  : gen byte Y=X*(EF1==13)
* === Sachsen (MZ 2005-2006: EF1=13 ==> MZ 2007: EF1=14) ===
qui for var x001 x002 x003 x004 x005 x006 xn   xng  x013 x014 ///  X
      \ new x133 x134 x135 x136 x137 x138 x139 x140 x141 x142 ///  Y
  : gen byte Y=X*(EF1==14)
* === Sachsen-Anhalt (MZ 2005-2006: EF1=14 ==> MZ 2007: EF1=15) ===
qui for var x001 x002 x003 x004 x005 x006 xn   xng  x013 x014 ///  X
      \ new x143 x144 x145 x146 x147 x148 x149 x150 x151 x152 ///  Y
  : gen byte Y=X*(EF1==15)
* === Thüringen (MZ 2005-2006 = 2007: EF1=16) ===
qui for var x001 x002 x003 x004 x005 x006 xn   xng  x013 x014 ///  X
      \ new x153 x154 x155 x156 x157 x158 x159 x160 x161 x162 ///  Y
  : gen byte Y=X*(EF1==16)

* Reduziertes Hochrechnungsmodell H3, H4
*    R1, R2: Ohne Unterscheidung nach Bevölkerungstyp
* Für Bremen (Annahme: R2 ) und Hamburg 
* === Bremen (MZ 2005-2006: EF1=05 ==> MZ 2007: EF1=4) ===
qui for var x001 x002 x003 x004 x005 x006 xn   xng  ///  X
      \ new x163 x164 x165 x166 x167 x168 x169 x170 ///  Y
  : gen byte Y=X*(EF1==4)
* === Hamburg (MZ 2005-2006: EF1=6 ==> MZ 2007: EF1=2) ===
qui for var x001 x002 x003 x004 x005 x006 xn   xng  ///  X
      \ new x171 x172 x173 x174 x175 x176 x177 x178 ///  Y
  : gen byte Y=X*(EF1==2)

* Reduziertes Hochrechnungsmodell H4
* Für Saarland: ohne Unterscheidung nach Bevölkerungstyp, aber 
*             R1: Staatsangehörigkeit (D, TR, EU25, nEU25)
* === Saarland (MZ 2005-2006: EF1=12 ==> MZ 2007: EF1=10) ===
qui for var x001 x002 x003 x004 x005 x006 x007 x008 x009 x010 x011 x012 ///
      \ new x179 x180 x181 x182 x183 x184 x185 x186 x187 x188 x189 x190 ///
  : gen byte Y=X*(EF1==10)

* === Nordrhein-Westfalen (MZ 2005-2006: EF1=10 ==> MZ 2007: EF1=5) ===
qui for var x001 x002 x003 x004 x005 x006 x007 x008 x009 x010 x011 x012 x013 x014 : replace X=X*(EF1==5)

* Hilfsmerkmale sind nur für Bevölkerung am Hauptwohnsitz definiert 
qui for var x001-x190 : replace X=X*(EF30>=1 & EF30<=2)

drop xn xng    // Zusammenfassungen werden nicht mehr benötigt

renpfix x    xp  // Umbenennung (xp := Personenebene)
renpfix xp00 xp
renpfix xp0  xp

* Arithm. Mittelwerte der Hilfsmerkmale auf Haushaltsebene bilden
* hhgr: Anzahl der Personen am Hauptwohnsitz pro hhnr
qui egen hhgr = total(EF30>=1 & EF30<=2), by(hhnr)
qui for var xp1-xp190 \ new x1-x190 : egen Y = total(X) if EF30>=1 & EF30<=2, by(hhnr)
qui for var x1-x190 : replace X = (X / hhgr) if EF30>=1 & EF30<=2
qui for var x1-x190 : replace X = 0 if X==.

order satznr hhnr  // ID
sort satznr // ID 
keep satznr hhnr x1-x190  // ID
label data "Hilfsmerkmale für gebundene Hochrechnung MZ 2007"
compress

save xvar07.dta, replace

exit
