/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
Diese Datei: xvar12.do
     Dateiformat: Dos\Windows
     Zeichensatz: Unicode (UTF-8 ohne BOM)   
Download: 
     https://www.gesis.org/missy/files/documents/MZ/misc/TR_10-03_STATA.zip
Version: 10/2019

Konstruktion der Hilfsmerkmale für Scientific Use File Mikrozensus 2012

Zusammenführung der Hilfsmerkmale mit SUF mittels Identifikator satznr

Siehe: 
Schimpl-Neimanns, Bernhard: Varianzschätzung für Mikrozensus 
Scientific Use Files ab 2005. GESIS-Technical Report Nr. 2010/03. 
Mannheim: GESIS.
  URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
       gesis_reihen/gesis_methodenberichte/2010/TechnicalReport_10-03.pdf
Überarbeitete Fassung veröffentlicht als:
Schimpl-Neimanns, Bernhard (2011): Schätzung des Stichprobenfehlers 
in Mikrozensus Scientific Use Files ab 2005, AStA Wirtschafts- und 
Sozialstatistisches Archiv 5 (1): 19-38. DOI: 10.1007/s11943-011-0092-4. 

Datenbeschreibung:
  https://www.gesis.org/missy/metadata/MZ/2012/

Änderungen gegenüber früheren Versionen:
* Syntax an Version Stata/MP 15.1 angepasst und vereinfacht
============================================================================= */  

* Stata/MP 15.1 
clear
capture log close
set more off
set dp comma
set varabbrev off

* Lokales Arbeitsverzeichnis eintragen, z. B. "c:\temp"
cd "Arbeitsverzeichnis"

log using "xvar12.log", text replace

* Daten einlesen, ggf. um Verzeichnis ergänzen oder ohne Variablenauswahl
use EF1   ///  Bundesland
    EF3   /// Nr. des Auswahlbezirks (systemfrei)
    EF4   /// Nr. des Haushalts im Auswahlbezirk (systemfrei)
    EF5a  /// Nr. der Person im Haushalt (systemfrei)
    EF5b  /// Jahresüberhang aus dem Vorjahr
    EF12  /// Berichtsquartal
    EF29  /// Erwerbstyp 
    EF30  /// Bevölkerung: Haupt- oder Nebenwohnsitz
    EF31  /// Bevölkerung: Privathaushalte
    EF44  /// Alter
    EF46  /// Geschlecht  
    EF117 /// Stellung im Beruf 
    EF369 /// 1. Staatsangehörigkeit
    EF371 /// Staatsangehörigkeit typisiert 
    EF570 /// Gebäudegrößenklasse 
    EF952 /// Hochrechnungsfaktor: Jahr (in 1000) 
  using "mz2012.dta", replace

* set output inform

* satznr für späteres Zusammenführen mit MZ
gen long satznr = _n
format satznr %6.0f
label var satznr "Fortlaufende Personennummer (Satznr. File)"

sort satznr

/* Poststratifikation
Die Hochrechnungsfaktoren der Originaldaten wurden nachträglich und ohne 
Berücksichtigung des Haushaltszusammenhangs angepasst an Randverteilungen nach:
- Geschlecht, 
- Altersgruppen (<15 Jahre, 15-44 Jahre, 45-64 Jahre, >=65 Jahre),
- Erwerbsstatus (erwerbstätig, nicht erwerbstätig) pro 
- Bundesland  
siehe www.gesis.org/missy/files/documents/MZ/readme/readme_suf2012.pdf    */

* Recodierung der Anpassungsmerkmale 
gen    ef1r = EF1 // 1=Schleswig-Holstein, ..., 16=Thüringen
recode EF44 (0/14=1) (15/44=2) (45/64=3) (65/95=4) (-7 -8 = -1) , gen(ef44r) // 1=0-14, 2=15-44, 3=45-54, 4=65+
recode EF46 (1=1) (2=2) (-7 -8 = -1), gen(ef46r) // 1=männlich 2=weiblich
recode EF29 (1=1) (2/4=2) (-7 -8 = -1) , gen(ef29r) // 1=erwerbstätig 2=nicht erwerbstätig

* Hilfsmerkmale für Varianzschätzung pro Merkmalskombination
gen byte x1   = (ef1r==1 & ef44r==1 & ef46r==1 & ef29r==2)
gen byte x2   = (ef1r==1 & ef44r==1 & ef46r==2 & ef29r==2)
gen byte x3   = (ef1r==1 & ef44r==2 & ef46r==1 & ef29r==1)
gen byte x4   = (ef1r==1 & ef44r==2 & ef46r==1 & ef29r==2)
gen byte x5   = (ef1r==1 & ef44r==2 & ef46r==2 & ef29r==1)
gen byte x6   = (ef1r==1 & ef44r==2 & ef46r==2 & ef29r==2)
gen byte x7   = (ef1r==1 & ef44r==3 & ef46r==1 & ef29r==1)
gen byte x8   = (ef1r==1 & ef44r==3 & ef46r==1 & ef29r==2)
gen byte x9   = (ef1r==1 & ef44r==3 & ef46r==2 & ef29r==1)
gen byte x10  = (ef1r==1 & ef44r==3 & ef46r==2 & ef29r==2)
gen byte x11  = (ef1r==1 & ef44r==4 & ef46r==1 & ef29r==1)
gen byte x12  = (ef1r==1 & ef44r==4 & ef46r==1 & ef29r==2)
gen byte x13  = (ef1r==1 & ef44r==4 & ef46r==2 & ef29r==1)
gen byte x14  = (ef1r==1 & ef44r==4 & ef46r==2 & ef29r==2)
gen byte x15  = (ef1r==2 & ef44r==1 & ef46r==1 & ef29r==2)
gen byte x16  = (ef1r==2 & ef44r==1 & ef46r==2 & ef29r==2)
gen byte x17  = (ef1r==2 & ef44r==2 & ef46r==1 & ef29r==1)
gen byte x18  = (ef1r==2 & ef44r==2 & ef46r==1 & ef29r==2)
gen byte x19  = (ef1r==2 & ef44r==2 & ef46r==2 & ef29r==1)
gen byte x20  = (ef1r==2 & ef44r==2 & ef46r==2 & ef29r==2)
gen byte x21  = (ef1r==2 & ef44r==3 & ef46r==1 & ef29r==1)
gen byte x22  = (ef1r==2 & ef44r==3 & ef46r==1 & ef29r==2)
gen byte x23  = (ef1r==2 & ef44r==3 & ef46r==2 & ef29r==1)
gen byte x24  = (ef1r==2 & ef44r==3 & ef46r==2 & ef29r==2)
gen byte x25  = (ef1r==2 & ef44r==4 & ef46r==1 & ef29r==1)
gen byte x26  = (ef1r==2 & ef44r==4 & ef46r==1 & ef29r==2)
gen byte x27  = (ef1r==2 & ef44r==4 & ef46r==2 & ef29r==1)
gen byte x28  = (ef1r==2 & ef44r==4 & ef46r==2 & ef29r==2)
gen byte x29  = (ef1r==3 & ef44r==1 & ef46r==1 & ef29r==2)
gen byte x30  = (ef1r==3 & ef44r==1 & ef46r==2 & ef29r==2)
gen byte x31  = (ef1r==3 & ef44r==2 & ef46r==1 & ef29r==1)
gen byte x32  = (ef1r==3 & ef44r==2 & ef46r==1 & ef29r==2)
gen byte x33  = (ef1r==3 & ef44r==2 & ef46r==2 & ef29r==1)
gen byte x34  = (ef1r==3 & ef44r==2 & ef46r==2 & ef29r==2)
gen byte x35  = (ef1r==3 & ef44r==3 & ef46r==1 & ef29r==1)
gen byte x36  = (ef1r==3 & ef44r==3 & ef46r==1 & ef29r==2)
gen byte x37  = (ef1r==3 & ef44r==3 & ef46r==2 & ef29r==1)
gen byte x38  = (ef1r==3 & ef44r==3 & ef46r==2 & ef29r==2)
gen byte x39  = (ef1r==3 & ef44r==4 & ef46r==1 & ef29r==1)
gen byte x40  = (ef1r==3 & ef44r==4 & ef46r==1 & ef29r==2)
gen byte x41  = (ef1r==3 & ef44r==4 & ef46r==2 & ef29r==1)
gen byte x42  = (ef1r==3 & ef44r==4 & ef46r==2 & ef29r==2)
gen byte x43  = (ef1r==4 & ef44r==1 & ef46r==1 & ef29r==2)
gen byte x44  = (ef1r==4 & ef44r==1 & ef46r==2 & ef29r==2)
gen byte x45  = (ef1r==4 & ef44r==2 & ef46r==1 & ef29r==1)
gen byte x46  = (ef1r==4 & ef44r==2 & ef46r==1 & ef29r==2)
gen byte x47  = (ef1r==4 & ef44r==2 & ef46r==2 & ef29r==1)
gen byte x48  = (ef1r==4 & ef44r==2 & ef46r==2 & ef29r==2)
gen byte x49  = (ef1r==4 & ef44r==3 & ef46r==1 & ef29r==1)
gen byte x50  = (ef1r==4 & ef44r==3 & ef46r==1 & ef29r==2)
gen byte x51  = (ef1r==4 & ef44r==3 & ef46r==2 & ef29r==1)
gen byte x52  = (ef1r==4 & ef44r==3 & ef46r==2 & ef29r==2)
gen byte x53  = (ef1r==4 & ef44r==4 & ef46r==1 & ef29r==1)
gen byte x54  = (ef1r==4 & ef44r==4 & ef46r==1 & ef29r==2)
gen byte x55  = (ef1r==4 & ef44r==4 & ef46r==2 & ef29r==1)
gen byte x56  = (ef1r==4 & ef44r==4 & ef46r==2 & ef29r==2)
gen byte x57  = (ef1r==5 & ef44r==1 & ef46r==1 & ef29r==2)
gen byte x58  = (ef1r==5 & ef44r==1 & ef46r==2 & ef29r==2)
gen byte x59  = (ef1r==5 & ef44r==2 & ef46r==1 & ef29r==1)
gen byte x60  = (ef1r==5 & ef44r==2 & ef46r==1 & ef29r==2)
gen byte x61  = (ef1r==5 & ef44r==2 & ef46r==2 & ef29r==1)
gen byte x62  = (ef1r==5 & ef44r==2 & ef46r==2 & ef29r==2)
gen byte x63  = (ef1r==5 & ef44r==3 & ef46r==1 & ef29r==1)
gen byte x64  = (ef1r==5 & ef44r==3 & ef46r==1 & ef29r==2)
gen byte x65  = (ef1r==5 & ef44r==3 & ef46r==2 & ef29r==1)
gen byte x66  = (ef1r==5 & ef44r==3 & ef46r==2 & ef29r==2)
gen byte x67  = (ef1r==5 & ef44r==4 & ef46r==1 & ef29r==1)
gen byte x68  = (ef1r==5 & ef44r==4 & ef46r==1 & ef29r==2)
gen byte x69  = (ef1r==5 & ef44r==4 & ef46r==2 & ef29r==1)
gen byte x70  = (ef1r==5 & ef44r==4 & ef46r==2 & ef29r==2)
gen byte x71  = (ef1r==6 & ef44r==1 & ef46r==1 & ef29r==2)
gen byte x72  = (ef1r==6 & ef44r==1 & ef46r==2 & ef29r==2)
gen byte x73  = (ef1r==6 & ef44r==2 & ef46r==1 & ef29r==1)
gen byte x74  = (ef1r==6 & ef44r==2 & ef46r==1 & ef29r==2)
gen byte x75  = (ef1r==6 & ef44r==2 & ef46r==2 & ef29r==1)
gen byte x76  = (ef1r==6 & ef44r==2 & ef46r==2 & ef29r==2)
gen byte x77  = (ef1r==6 & ef44r==3 & ef46r==1 & ef29r==1)
gen byte x78  = (ef1r==6 & ef44r==3 & ef46r==1 & ef29r==2)
gen byte x79  = (ef1r==6 & ef44r==3 & ef46r==2 & ef29r==1)
gen byte x80  = (ef1r==6 & ef44r==3 & ef46r==2 & ef29r==2)
gen byte x81  = (ef1r==6 & ef44r==4 & ef46r==1 & ef29r==1)
gen byte x82  = (ef1r==6 & ef44r==4 & ef46r==1 & ef29r==2)
gen byte x83  = (ef1r==6 & ef44r==4 & ef46r==2 & ef29r==1)
gen byte x84  = (ef1r==6 & ef44r==4 & ef46r==2 & ef29r==2)
gen byte x85  = (ef1r==7 & ef44r==1 & ef46r==1 & ef29r==2)
gen byte x86  = (ef1r==7 & ef44r==1 & ef46r==2 & ef29r==2)
gen byte x87  = (ef1r==7 & ef44r==2 & ef46r==1 & ef29r==1)
gen byte x88  = (ef1r==7 & ef44r==2 & ef46r==1 & ef29r==2)
gen byte x89  = (ef1r==7 & ef44r==2 & ef46r==2 & ef29r==1)
gen byte x90  = (ef1r==7 & ef44r==2 & ef46r==2 & ef29r==2)
gen byte x91  = (ef1r==7 & ef44r==3 & ef46r==1 & ef29r==1)
gen byte x92  = (ef1r==7 & ef44r==3 & ef46r==1 & ef29r==2)
gen byte x93  = (ef1r==7 & ef44r==3 & ef46r==2 & ef29r==1)
gen byte x94  = (ef1r==7 & ef44r==3 & ef46r==2 & ef29r==2)
gen byte x95  = (ef1r==7 & ef44r==4 & ef46r==1 & ef29r==1)
gen byte x96  = (ef1r==7 & ef44r==4 & ef46r==1 & ef29r==2)
gen byte x97  = (ef1r==7 & ef44r==4 & ef46r==2 & ef29r==1)
gen byte x98  = (ef1r==7 & ef44r==4 & ef46r==2 & ef29r==2)
gen byte x99  = (ef1r==8 & ef44r==1 & ef46r==1 & ef29r==2)
gen byte x100 = (ef1r==8 & ef44r==1 & ef46r==2 & ef29r==2)
gen byte x101 = (ef1r==8 & ef44r==2 & ef46r==1 & ef29r==1)
gen byte x102 = (ef1r==8 & ef44r==2 & ef46r==1 & ef29r==2)
gen byte x103 = (ef1r==8 & ef44r==2 & ef46r==2 & ef29r==1)
gen byte x104 = (ef1r==8 & ef44r==2 & ef46r==2 & ef29r==2)
gen byte x105 = (ef1r==8 & ef44r==3 & ef46r==1 & ef29r==1)
gen byte x106 = (ef1r==8 & ef44r==3 & ef46r==1 & ef29r==2)
gen byte x107 = (ef1r==8 & ef44r==3 & ef46r==2 & ef29r==1)
gen byte x108 = (ef1r==8 & ef44r==3 & ef46r==2 & ef29r==2)
gen byte x109 = (ef1r==8 & ef44r==4 & ef46r==1 & ef29r==1)
gen byte x110 = (ef1r==8 & ef44r==4 & ef46r==1 & ef29r==2)
gen byte x111 = (ef1r==8 & ef44r==4 & ef46r==2 & ef29r==1)
gen byte x112 = (ef1r==8 & ef44r==4 & ef46r==2 & ef29r==2)
gen byte x113 = (ef1r==9 & ef44r==1 & ef46r==1 & ef29r==2)
gen byte x114 = (ef1r==9 & ef44r==1 & ef46r==2 & ef29r==2)
gen byte x115 = (ef1r==9 & ef44r==2 & ef46r==1 & ef29r==1)
gen byte x116 = (ef1r==9 & ef44r==2 & ef46r==1 & ef29r==2)
gen byte x117 = (ef1r==9 & ef44r==2 & ef46r==2 & ef29r==1)
gen byte x118 = (ef1r==9 & ef44r==2 & ef46r==2 & ef29r==2)
gen byte x119 = (ef1r==9 & ef44r==3 & ef46r==1 & ef29r==1)
gen byte x120 = (ef1r==9 & ef44r==3 & ef46r==1 & ef29r==2)
gen byte x121 = (ef1r==9 & ef44r==3 & ef46r==2 & ef29r==1)
gen byte x122 = (ef1r==9 & ef44r==3 & ef46r==2 & ef29r==2)
gen byte x123 = (ef1r==9 & ef44r==4 & ef46r==1 & ef29r==1)
gen byte x124 = (ef1r==9 & ef44r==4 & ef46r==1 & ef29r==2)
gen byte x125 = (ef1r==9 & ef44r==4 & ef46r==2 & ef29r==1)
gen byte x126 = (ef1r==9 & ef44r==4 & ef46r==2 & ef29r==2)
gen byte x127 = (ef1r==10 & ef44r==1 & ef46r==1 & ef29r==2)
gen byte x128 = (ef1r==10 & ef44r==1 & ef46r==2 & ef29r==2)
gen byte x129 = (ef1r==10 & ef44r==2 & ef46r==1 & ef29r==1)
gen byte x130 = (ef1r==10 & ef44r==2 & ef46r==1 & ef29r==2)
gen byte x131 = (ef1r==10 & ef44r==2 & ef46r==2 & ef29r==1)
gen byte x132 = (ef1r==10 & ef44r==2 & ef46r==2 & ef29r==2)
gen byte x133 = (ef1r==10 & ef44r==3 & ef46r==1 & ef29r==1)
gen byte x134 = (ef1r==10 & ef44r==3 & ef46r==1 & ef29r==2)
gen byte x135 = (ef1r==10 & ef44r==3 & ef46r==2 & ef29r==1)
gen byte x136 = (ef1r==10 & ef44r==3 & ef46r==2 & ef29r==2)
gen byte x137 = (ef1r==10 & ef44r==4 & ef46r==1 & ef29r==1)
gen byte x138 = (ef1r==10 & ef44r==4 & ef46r==1 & ef29r==2)
gen byte x139 = (ef1r==10 & ef44r==4 & ef46r==2 & ef29r==1)
gen byte x140 = (ef1r==10 & ef44r==4 & ef46r==2 & ef29r==2)
gen byte x141 = (ef1r==11 & ef44r==1 & ef46r==1 & ef29r==2)
gen byte x142 = (ef1r==11 & ef44r==1 & ef46r==2 & ef29r==2)
gen byte x143 = (ef1r==11 & ef44r==2 & ef46r==1 & ef29r==1)
gen byte x144 = (ef1r==11 & ef44r==2 & ef46r==1 & ef29r==2)
gen byte x145 = (ef1r==11 & ef44r==2 & ef46r==2 & ef29r==1)
gen byte x146 = (ef1r==11 & ef44r==2 & ef46r==2 & ef29r==2)
gen byte x147 = (ef1r==11 & ef44r==3 & ef46r==1 & ef29r==1)
gen byte x148 = (ef1r==11 & ef44r==3 & ef46r==1 & ef29r==2)
gen byte x149 = (ef1r==11 & ef44r==3 & ef46r==2 & ef29r==1)
gen byte x150 = (ef1r==11 & ef44r==3 & ef46r==2 & ef29r==2)
gen byte x151 = (ef1r==11 & ef44r==4 & ef46r==1 & ef29r==1)
gen byte x152 = (ef1r==11 & ef44r==4 & ef46r==1 & ef29r==2)
gen byte x153 = (ef1r==11 & ef44r==4 & ef46r==2 & ef29r==1)
gen byte x154 = (ef1r==11 & ef44r==4 & ef46r==2 & ef29r==2)
gen byte x155 = (ef1r==12 & ef44r==1 & ef46r==1 & ef29r==2)
gen byte x156 = (ef1r==12 & ef44r==1 & ef46r==2 & ef29r==2)
gen byte x157 = (ef1r==12 & ef44r==2 & ef46r==1 & ef29r==1)
gen byte x158 = (ef1r==12 & ef44r==2 & ef46r==1 & ef29r==2)
gen byte x159 = (ef1r==12 & ef44r==2 & ef46r==2 & ef29r==1)
gen byte x160 = (ef1r==12 & ef44r==2 & ef46r==2 & ef29r==2)
gen byte x161 = (ef1r==12 & ef44r==3 & ef46r==1 & ef29r==1)
gen byte x162 = (ef1r==12 & ef44r==3 & ef46r==1 & ef29r==2)
gen byte x163 = (ef1r==12 & ef44r==3 & ef46r==2 & ef29r==1)
gen byte x164 = (ef1r==12 & ef44r==3 & ef46r==2 & ef29r==2)
gen byte x165 = (ef1r==12 & ef44r==4 & ef46r==1 & ef29r==1)
gen byte x166 = (ef1r==12 & ef44r==4 & ef46r==1 & ef29r==2)
gen byte x167 = (ef1r==12 & ef44r==4 & ef46r==2 & ef29r==1)
gen byte x168 = (ef1r==12 & ef44r==4 & ef46r==2 & ef29r==2)
gen byte x169 = (ef1r==13 & ef44r==1 & ef46r==1 & ef29r==2)
gen byte x170 = (ef1r==13 & ef44r==1 & ef46r==2 & ef29r==2)
gen byte x171 = (ef1r==13 & ef44r==2 & ef46r==1 & ef29r==1)
gen byte x172 = (ef1r==13 & ef44r==2 & ef46r==1 & ef29r==2)
gen byte x173 = (ef1r==13 & ef44r==2 & ef46r==2 & ef29r==1)
gen byte x174 = (ef1r==13 & ef44r==2 & ef46r==2 & ef29r==2)
gen byte x175 = (ef1r==13 & ef44r==3 & ef46r==1 & ef29r==1)
gen byte x176 = (ef1r==13 & ef44r==3 & ef46r==1 & ef29r==2)
gen byte x177 = (ef1r==13 & ef44r==3 & ef46r==2 & ef29r==1)
gen byte x178 = (ef1r==13 & ef44r==3 & ef46r==2 & ef29r==2)
gen byte x179 = (ef1r==13 & ef44r==4 & ef46r==1 & ef29r==1)
gen byte x180 = (ef1r==13 & ef44r==4 & ef46r==1 & ef29r==2)
gen byte x181 = (ef1r==13 & ef44r==4 & ef46r==2 & ef29r==1)
gen byte x182 = (ef1r==13 & ef44r==4 & ef46r==2 & ef29r==2)
gen byte x183 = (ef1r==14 & ef44r==1 & ef46r==1 & ef29r==2)
gen byte x184 = (ef1r==14 & ef44r==1 & ef46r==2 & ef29r==2)
gen byte x185 = (ef1r==14 & ef44r==2 & ef46r==1 & ef29r==1)
gen byte x186 = (ef1r==14 & ef44r==2 & ef46r==1 & ef29r==2)
gen byte x187 = (ef1r==14 & ef44r==2 & ef46r==2 & ef29r==1)
gen byte x188 = (ef1r==14 & ef44r==2 & ef46r==2 & ef29r==2)
gen byte x189 = (ef1r==14 & ef44r==3 & ef46r==1 & ef29r==1)
gen byte x190 = (ef1r==14 & ef44r==3 & ef46r==1 & ef29r==2)
gen byte x191 = (ef1r==14 & ef44r==3 & ef46r==2 & ef29r==1)
gen byte x192 = (ef1r==14 & ef44r==3 & ef46r==2 & ef29r==2)
gen byte x193 = (ef1r==14 & ef44r==4 & ef46r==1 & ef29r==1)
gen byte x194 = (ef1r==14 & ef44r==4 & ef46r==1 & ef29r==2)
gen byte x195 = (ef1r==14 & ef44r==4 & ef46r==2 & ef29r==1)
gen byte x196 = (ef1r==14 & ef44r==4 & ef46r==2 & ef29r==2)
gen byte x197 = (ef1r==15 & ef44r==1 & ef46r==1 & ef29r==2)
gen byte x198 = (ef1r==15 & ef44r==1 & ef46r==2 & ef29r==2)
gen byte x199 = (ef1r==15 & ef44r==2 & ef46r==1 & ef29r==1)
gen byte x200 = (ef1r==15 & ef44r==2 & ef46r==1 & ef29r==2)
gen byte x201 = (ef1r==15 & ef44r==2 & ef46r==2 & ef29r==1)
gen byte x202 = (ef1r==15 & ef44r==2 & ef46r==2 & ef29r==2)
gen byte x203 = (ef1r==15 & ef44r==3 & ef46r==1 & ef29r==1)
gen byte x204 = (ef1r==15 & ef44r==3 & ef46r==1 & ef29r==2)
gen byte x205 = (ef1r==15 & ef44r==3 & ef46r==2 & ef29r==1)
gen byte x206 = (ef1r==15 & ef44r==3 & ef46r==2 & ef29r==2)
gen byte x207 = (ef1r==15 & ef44r==4 & ef46r==1 & ef29r==1)
gen byte x208 = (ef1r==15 & ef44r==4 & ef46r==1 & ef29r==2)
gen byte x209 = (ef1r==15 & ef44r==4 & ef46r==2 & ef29r==1)
gen byte x210 = (ef1r==15 & ef44r==4 & ef46r==2 & ef29r==2)
gen byte x211 = (ef1r==16 & ef44r==1 & ef46r==1 & ef29r==2)
gen byte x212 = (ef1r==16 & ef44r==1 & ef46r==2 & ef29r==2)
gen byte x213 = (ef1r==16 & ef44r==2 & ef46r==1 & ef29r==1)
gen byte x214 = (ef1r==16 & ef44r==2 & ef46r==1 & ef29r==2)
gen byte x215 = (ef1r==16 & ef44r==2 & ef46r==2 & ef29r==1)
gen byte x216 = (ef1r==16 & ef44r==2 & ef46r==2 & ef29r==2)
gen byte x217 = (ef1r==16 & ef44r==3 & ef46r==1 & ef29r==1)
gen byte x218 = (ef1r==16 & ef44r==3 & ef46r==1 & ef29r==2)
gen byte x219 = (ef1r==16 & ef44r==3 & ef46r==2 & ef29r==1)
gen byte x220 = (ef1r==16 & ef44r==3 & ef46r==2 & ef29r==2)
gen byte x221 = (ef1r==16 & ef44r==4 & ef46r==1 & ef29r==1)
gen byte x222 = (ef1r==16 & ef44r==4 & ef46r==1 & ef29r==2)
gen byte x223 = (ef1r==16 & ef44r==4 & ef46r==2 & ef29r==1)
gen byte x224 = (ef1r==16 & ef44r==4 & ef46r==2 & ef29r==2)

* Die Hilfsmerkmale sind nur für die Bevölkerung am Hauptwohnsitz definiert 
qui for var x1-x224 : replace X=X*(EF30>=1 & EF30<=2)

sort satznr 

keep satznr x1-x224 

label data "Hilfsmerkmale für gebundene Hochrechnung MZ 2012"

compress

save "xvar12.dta", replace

exit
